@@ -23,9 +23,10 @@
 #endif
 
 #include <gdk/gdkkeysyms.h>
-#include <libxfce4ui/libxfce4ui.h>
 #include <libxfce4util/libxfce4util.h>
 
+#include "libxfce4ui/libxfce4ui.h"
+
 #include "xfce-shortcut-dialog.h"
 #include "xfce-shortcuts.h"
 
