@@ -29,7 +29,7 @@
  **/
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #ifdef HAVE_STDARG_H
@@ -37,13 +37,12 @@
 #endif
 
 #include <gdk/gdkkeysyms.h>
-
 #include <libxfce4util/libxfce4util.h>
 
-#include <libxfce4ui/xfce-titled-dialog.h>
-#include <libxfce4ui/libxfce4ui-private.h>
-#include <libxfce4ui/libxfce4ui-alias.h>
-#include <libxfce4ui/xfce-gtk-extensions.h>
+#include "libxfce4ui-private.h"
+#include "xfce-gtk-extensions.h"
+#include "xfce-titled-dialog.h"
+#include "libxfce4ui-alias.h"
 
 
 #define XFCE_TITLED_DIALOG_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFCE_TYPE_TITLED_DIALOG, XfceTitledDialogPrivate))
@@ -58,24 +57,28 @@ enum
 };
 
 
-static GObject *xfce_titled_dialog_constructor    (GType                   type,
-                                                   guint                   n_construct_params,
-                                                   GObjectConstructParam  *construct_params);
-static void     xfce_titled_dialog_constructed    (GObject                *object);
-static void     xfce_titled_dialog_finalize       (GObject                *object);
-static void     xfce_titled_dialog_get_property   (GObject                *object,
-                                                   guint                   prop_id,
-                                                   GValue                 *value,
-                                                   GParamSpec             *pspec);
-static void     xfce_titled_dialog_set_property   (GObject                *object,
-                                                   guint                   prop_id,
-                                                   const GValue           *value,
-                                                   GParamSpec             *pspec);
-static void     xfce_titled_dialog_close          (GtkDialog              *dialog);
-static void     xfce_titled_dialog_update_window  (XfceTitledDialog       *titled_dialog);
-static void     xfce_titled_dialog_update_layout  (GObject                *settings,
-                                                   GParamSpec             *pspec,
-                                                   XfceTitledDialog       *titled_dialog);
+static GObject *
+xfce_titled_dialog_constructor (GType type,
+                                guint n_construct_params,
+                                GObjectConstructParam *construct_params);
+static void
+xfce_titled_dialog_constructed (GObject *object);
+static void
+xfce_titled_dialog_finalize (GObject *object);
+static void
+xfce_titled_dialog_get_property (GObject *object,
+                                 guint prop_id,
+                                 GValue *value,
+                                 GParamSpec *pspec);
+static void
+xfce_titled_dialog_set_property (GObject *object,
+                                 guint prop_id,
+                                 const GValue *value,
+                                 GParamSpec *pspec);
+static void
+xfce_titled_dialog_close (GtkDialog *dialog);
+static void
+xfce_titled_dialog_update_window (XfceTitledDialog *titled_dialog);
 
 
 
@@ -85,8 +88,8 @@ struct _XfceTitledDialogPrivate
   GtkWidget *action_area;
   GtkWidget *subtitle_label;
   GtkWidget *subtitle_separator;
-  gchar     *subtitle;
-  gboolean   use_header;
+  gchar *subtitle;
+  gboolean use_header;
 };
 
 typedef struct _ResponseData ResponseData;
@@ -106,8 +109,8 @@ static void
 xfce_titled_dialog_class_init (XfceTitledDialogClass *klass)
 {
   GtkDialogClass *gtkdialog_class;
-  GtkBindingSet  *binding_set;
-  GObjectClass   *gobject_class;
+  GtkBindingSet *binding_set;
+  GObjectClass *gobject_class;
 
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->constructor = xfce_titled_dialog_constructor;
@@ -131,7 +134,7 @@ xfce_titled_dialog_class_init (XfceTitledDialogClass *klass)
                                                         "subtitle",
                                                         NULL,
                                                         G_PARAM_READWRITE
-                                                        | G_PARAM_STATIC_STRINGS));
+                                                          | G_PARAM_STATIC_STRINGS));
 
   /* connect additional key bindings to the GtkDialog::close action signal */
   binding_set = gtk_binding_set_by_class (klass);
@@ -142,15 +145,13 @@ xfce_titled_dialog_class_init (XfceTitledDialogClass *klass)
 
 
 static GObject *
-xfce_titled_dialog_constructor (GType                  type,
-                                guint                  n_construct_params,
+xfce_titled_dialog_constructor (GType type,
+                                guint n_construct_params,
                                 GObjectConstructParam *construct_params)
 {
   GObject *object;
 
-  object = G_OBJECT_CLASS (xfce_titled_dialog_parent_class)->constructor (type,
-                                                           n_construct_params,
-                                                           construct_params);
+  object = G_OBJECT_CLASS (xfce_titled_dialog_parent_class)->constructor (type, n_construct_params, construct_params);
 
   return object;
 }
@@ -168,9 +169,9 @@ xfce_titled_dialog_init (XfceTitledDialog *titled_dialog)
   settings = gtk_settings_get_default ();
   g_object_get (settings, "gtk-dialogs-use-header", &titled_dialog->priv->use_header, NULL);
 
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   titled_dialog->priv->action_area = gtk_dialog_get_action_area (GTK_DIALOG (titled_dialog));
-G_GNUC_END_IGNORE_DEPRECATIONS
+  G_GNUC_END_IGNORE_DEPRECATIONS
 
   if (titled_dialog->priv->use_header)
     {
@@ -186,11 +187,6 @@ G_GNUC_END_IGNORE_DEPRECATIONS
       /* Adjust window buttons and window placement */
       gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (titled_dialog->priv->headerbar), TRUE);
       g_signal_connect (G_OBJECT (titled_dialog), "notify::window", G_CALLBACK (xfce_titled_dialog_update_window), NULL);
-
-      /* Add icon to the layout if needed */
-      xfce_titled_dialog_update_layout (G_OBJECT (settings), NULL, titled_dialog);
-      g_signal_connect_object (settings, "notify::gtk-decoration-layout",
-                               G_CALLBACK (xfce_titled_dialog_update_layout), titled_dialog, 0);
     }
   else
     {
@@ -218,7 +214,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
       gtk_style_context_add_class (gtk_widget_get_style_context (widget), "xfce-titled-dialog-separator");
 
       gtk_box_pack_start (GTK_BOX (vbox), content_area, TRUE, TRUE, 0);
-      g_object_unref (G_OBJECT(content_area));
+      g_object_unref (G_OBJECT (content_area));
     }
 }
 
@@ -289,9 +285,9 @@ xfce_titled_dialog_finalize (GObject *object)
 
 
 static void
-xfce_titled_dialog_get_property (GObject    *object,
-                                 guint       prop_id,
-                                 GValue     *value,
+xfce_titled_dialog_get_property (GObject *object,
+                                 guint prop_id,
+                                 GValue *value,
                                  GParamSpec *pspec)
 {
   XfceTitledDialog *titled_dialog = XFCE_TITLED_DIALOG (object);
@@ -311,10 +307,10 @@ xfce_titled_dialog_get_property (GObject    *object,
 
 
 static void
-xfce_titled_dialog_set_property (GObject      *object,
-                                 guint         prop_id,
+xfce_titled_dialog_set_property (GObject *object,
+                                 guint prop_id,
                                  const GValue *value,
-                                 GParamSpec   *pspec)
+                                 GParamSpec *pspec)
 {
   XfceTitledDialog *titled_dialog = XFCE_TITLED_DIALOG (object);
 
@@ -342,7 +338,7 @@ xfce_titled_dialog_close (GtkDialog *dialog)
     {
       /* send a delete event to the dialog */
       event = gdk_event_new (GDK_DELETE);
-      event->any.window = g_object_ref (gtk_widget_get_window(GTK_WIDGET (dialog)));
+      event->any.window = g_object_ref (gtk_widget_get_window (GTK_WIDGET (dialog)));
       event->any.send_event = TRUE;
       gtk_main_do_event (event);
       gdk_event_free (event);
@@ -367,30 +363,6 @@ xfce_titled_dialog_update_window (XfceTitledDialog *titled_dialog)
 
 
 
-static void
-xfce_titled_dialog_update_layout (GObject *settings,
-                                  GParamSpec *pspec,
-                                  XfceTitledDialog *titled_dialog)
-{
-  gchar *layout;
-
-  g_object_get (settings, "gtk-decoration-layout", &layout, NULL);
-
-  /* add icon on the far left of the header bar if not already present */
-  if (g_strstr_len (layout, -1, "icon") == NULL)
-    {
-      const gchar *separator = (g_strstr_len (layout, -1, ":") == NULL) ? ":" : ",";
-      gchar *layout_with_icon = g_strconcat ("icon", separator, layout, NULL);
-      g_free (layout);
-      layout = layout_with_icon;
-    }
-
-  gtk_header_bar_set_decoration_layout (GTK_HEADER_BAR (titled_dialog->priv->headerbar), layout);
-  g_free (layout);
-}
-
-
-
 /* Borrowed from gtkdialog.c */
 static void
 response_data_free (gpointer data)
@@ -402,7 +374,7 @@ response_data_free (gpointer data)
 
 static ResponseData *
 get_response_data (GtkWidget *widget,
-                   gboolean   create)
+                   gboolean create)
 {
   ResponseData *ad = g_object_get_data (G_OBJECT (widget),
                                         "gtk-dialog-response-data");
@@ -412,7 +384,7 @@ get_response_data (GtkWidget *widget,
       ad = g_slice_new (ResponseData);
 
       g_object_set_data_full (G_OBJECT (widget),
-                              I_("gtk-dialog-response-data"),
+                              I_ ("gtk-dialog-response-data"),
                               ad,
                               response_data_free);
     }
@@ -437,7 +409,7 @@ action_widget_activated (GtkWidget *widget, GtkDialog *dialog)
 static void
 add_response_data (GtkDialog *dialog,
                    GtkWidget *child,
-                   gint       response_id)
+                   gint response_id)
 {
   ResponseData *ad;
   guint signal_id;
@@ -472,7 +444,7 @@ add_response_data (GtkDialog *dialog,
  *
  * Return value: the newly allocated #XfceTitledDialog.
  **/
-GtkWidget*
+GtkWidget *
 xfce_titled_dialog_new (void)
 {
   return g_object_new (XFCE_TYPE_TITLED_DIALOG, NULL);
@@ -495,18 +467,18 @@ xfce_titled_dialog_new (void)
  *
  * Deprecated: 4.16: Use #xfce_titled_dialog_new_with_mixed_buttons instead.
  **/
-GtkWidget*
-xfce_titled_dialog_new_with_buttons (const gchar    *title,
-                                     GtkWindow      *parent,
-                                     GtkDialogFlags  flags,
-                                     const gchar    *first_button_text,
+GtkWidget *
+xfce_titled_dialog_new_with_buttons (const gchar *title,
+                                     GtkWindow *parent,
+                                     GtkDialogFlags flags,
+                                     const gchar *first_button_text,
                                      ...)
 {
   const gchar *button_text;
-  GtkWidget   *dialog;
-  GtkWidget   *button;
-  va_list      args;
-  gint         response_id;
+  GtkWidget *dialog;
+  GtkWidget *button;
+  va_list args;
+  gint response_id;
 
   /* allocate the dialog */
   dialog = g_object_new (XFCE_TYPE_TITLED_DIALOG,
@@ -521,12 +493,12 @@ xfce_titled_dialog_new_with_buttons (const gchar    *title,
 
   /* add all additional buttons */
   va_start (args, first_button_text);
-  for (button_text = first_button_text; button_text != NULL; )
+  for (button_text = first_button_text; button_text != NULL;)
     {
       response_id = va_arg (args, gint);
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+      G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       button = gtk_button_new_from_stock (button_text);
-G_GNUC_END_IGNORE_DEPRECATIONS
+      G_GNUC_END_IGNORE_DEPRECATIONS
       xfce_titled_dialog_add_action_widget (XFCE_TITLED_DIALOG (dialog), button, response_id);
       button_text = va_arg (args, const gchar *);
     }
@@ -554,19 +526,19 @@ G_GNUC_END_IGNORE_DEPRECATIONS
  * Since: 4.14
  *
  **/
-GtkWidget*
-xfce_titled_dialog_new_with_mixed_buttons (const gchar    *title,
-                                           GtkWindow      *parent,
-                                           GtkDialogFlags  flags,
-                                           const gchar    *first_button_icon_name,
-                                           const gchar    *first_button_text,
+GtkWidget *
+xfce_titled_dialog_new_with_mixed_buttons (const gchar *title,
+                                           GtkWindow *parent,
+                                           GtkDialogFlags flags,
+                                           const gchar *first_button_icon_name,
+                                           const gchar *first_button_text,
                                            ...)
 {
   const gchar *icon_name;
   const gchar *button_text;
-  GtkWidget   *dialog;
-  va_list      args;
-  gint         response_id;
+  GtkWidget *dialog;
+  va_list args;
+  gint response_id;
 
   /* allocate the dialog */
   dialog = g_object_new (XFCE_TYPE_TITLED_DIALOG,
@@ -649,8 +621,8 @@ xfce_titled_dialog_create_action_area (XfceTitledDialog *titled_dialog)
  **/
 GtkWidget *
 xfce_titled_dialog_add_button (XfceTitledDialog *titled_dialog,
-                               const gchar      *button_text,
-                               gint              response_id)
+                               const gchar *button_text,
+                               gint response_id)
 {
   GtkWidget *button;
 
@@ -684,8 +656,8 @@ xfce_titled_dialog_add_button (XfceTitledDialog *titled_dialog,
  **/
 void
 xfce_titled_dialog_add_action_widget (XfceTitledDialog *titled_dialog,
-                                      GtkWidget        *child,
-                                      gint              response_id)
+                                      GtkWidget *child,
+                                      gint response_id)
 {
   g_return_if_fail (XFCE_IS_TITLED_DIALOG (titled_dialog));
   g_return_if_fail (GTK_IS_WIDGET (titled_dialog->priv->action_area));
@@ -719,10 +691,10 @@ xfce_titled_dialog_add_action_widget (XfceTitledDialog *titled_dialog,
  **/
 void
 xfce_titled_dialog_set_default_response (XfceTitledDialog *titled_dialog,
-                                         gint              response_id)
+                                         gint response_id)
 {
-  GList     *children;
-  GList     *tmp_list;
+  GList *children;
+  GList *tmp_list;
 
   g_return_if_fail (XFCE_IS_TITLED_DIALOG (titled_dialog));
 
@@ -757,7 +729,7 @@ xfce_titled_dialog_set_default_response (XfceTitledDialog *titled_dialog,
  *
  * Return value: the subtitle of @titled_dialog, or %NULL.
  **/
-const gchar*
+const gchar *
 xfce_titled_dialog_get_subtitle (XfceTitledDialog *titled_dialog)
 {
   g_return_val_if_fail (XFCE_IS_TITLED_DIALOG (titled_dialog), NULL);
@@ -779,7 +751,7 @@ xfce_titled_dialog_get_subtitle (XfceTitledDialog *titled_dialog)
  **/
 void
 xfce_titled_dialog_set_subtitle (XfceTitledDialog *titled_dialog,
-                                 const gchar      *subtitle)
+                                 const gchar *subtitle)
 {
   g_return_if_fail (XFCE_IS_TITLED_DIALOG (titled_dialog));
   g_return_if_fail (subtitle == NULL || g_utf8_validate (subtitle, -1, NULL));
@@ -810,4 +782,4 @@ xfce_titled_dialog_set_subtitle (XfceTitledDialog *titled_dialog,
 
 
 #define __XFCE_TITLED_DIALOG_C__
-#include <libxfce4ui/libxfce4ui-aliasdef.c>
+#include "libxfce4ui-aliasdef.c"
