@@ -32,9 +32,10 @@
 #endif
 
 #include <gtk/gtk.h>
-#include <libxfce4ui/libxfce4ui.h>
 #include <libxfce4util/libxfce4util.h>
 
+#include "libxfce4ui/libxfce4ui.h"
+
 #include "about-dialog-ui.h"
 #include "contributors.h"
 
@@ -532,7 +533,7 @@ main (gint argc,
   if (G_UNLIKELY (opt_version))
     {
       g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-      g_print ("%s\n", "Copyright (c) 2008-2024");
+      g_print ("%s\n", "Copyright (c) 2008-" COPYRIGHT_YEAR);
       g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
       g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
       g_print ("\n");
